@@ -1,8 +1,7 @@
-#!/usr/bin/env bash
 cat > $1/demos/Makefile.am <<EOF
 noinst_PROGRAMS = demo
 
 demo_SOURCES = demo.c
-demo_CPPFLAGS = -I\$(top_builddir)/src
+demo_CPPFLAGS = -I\$(top_srcdir)/src
 demo_LDADD = -L\$(top_builddir)/src -l${1#lib}
 EOF
