@@ -1,4 +1,3 @@
-#!/usr/bin/env bash
 cat > $1/configure.ac <<EOF
 AC_INIT([$2], [0.0.0], [$3], [$1])
 AC_CONFIG_HEADERS(config.h)
@@ -6,6 +5,11 @@ AM_INIT_AUTOMAKE(no-dist-gzip dist-bzip2)
 
 # Checks for programs.
 AC_PROG_CC
+EOF
+if [[ -n $4 ]]
+then echo "AM_PROG_CC_C_O" >> $1/configure.ac
+fi
+cat >> $1/configure.ac <<EOF
 
 # Checks for libraries.
 EOF
