@@ -1,4 +1,4 @@
-#!/usr/bin/env bash
+#! /usr/bin/env bash
 
 # Copyright (C) 2007 Juan Manuel Borges Caño
 
@@ -22,12 +22,6 @@ MP_DESCRIPTION="[@]pkgdescription[@]"
 MP_BUGREPORT="[@]pkgbugreport[@]"
 MP_DATADIR="[@]pkgdatadir[@]"
 
-function mp_is_project
-{
-	b1=$(basename $1)
-	[ -d $1 ] && [[ $b1 != "project" ]] && [[ $b1 != "project-lib" ]]
-}
-
 function mp_usage
 {
 	printf "Usage: $MP [OPTION]...\n"
@@ -55,6 +49,11 @@ function mp_version
 	exit 0
 }
 
+function mp_is_project
+{
+	[[ -d $1 ]] && [[ -a $1/mkproject.sh ]] && [[ -a $1/project ]]
+}
+
 function mp_ls_projects
 {
 	for d in "${MP_DATADIR}"/*
@@ -66,11 +65,34 @@ function mp_ls_projects
 	exit 0
 }
 
+function mp_info
+{
+	echo "Try \`$MP --help' for more information."
+}
+
 function mp_error
 {
-	echo "$MP: $@"
-	echo "Try \`$MP --help' for more information."
-	exit 1
+	echo "$MP: $@"; mp_info; exit 1
+}
+
+function mp_cat
+{
+	sed -e "s,^,$MP: ," "$1"
+}
+
+function mp_check_and_echo
+{
+	if [[ $? == 0 ]]
+	then
+		echo "done"
+	else
+		echo "error"
+		if [[ -n "$1" ]]
+		then mp_cat "$1"
+		fi
+		mp_info
+		exit 1
+	fi
 }
 
 TEMP=$(getopt -o "ls:t:p:d:D:a:b:hv" \
@@ -118,4 +140,10 @@ if [[ -z $BUGREPORT ]]
 fi
 
 source "${MP_DATADIR}/mp.sh" "$SKELETON"
-source "${MP_DATADIR}/$SKELETON/mkproject.sh"
+if mp_is_project "$MP_DATADIR/$SKELETON"
+then
+	MP_ERROR_LOG=$(mktemp)
+	source "${MP_DATADIR}/$SKELETON/mkproject.sh"
+else
+	mp_error "project skeleton not found"
+fi
